@@ -1,5 +1,7 @@
 // Copyright Fauna, Inc.
 // SPDX-License-Identifier: MIT-0
 
-pub mod values;
-pub mod verbs;
\ No newline at end of file
+pub mod parser;
+pub mod serializer;
+mod values;
+mod verbs;
